summaryrefslogtreecommitdiffstats
path: root/net/url_request/url_request_throttler_manager.cc
diff options
context:
space:
mode:
Diffstat (limited to 'net/url_request/url_request_throttler_manager.cc')
-rw-r--r--net/url_request/url_request_throttler_manager.cc9
1 files changed, 5 insertions, 4 deletions
diff --git a/net/url_request/url_request_throttler_manager.cc b/net/url_request/url_request_throttler_manager.cc
index c2fa430..5c50558 100644
--- a/net/url_request/url_request_throttler_manager.cc
+++ b/net/url_request/url_request_throttler_manager.cc
@@ -28,12 +28,12 @@ URLRequestThrottlerManager::URLRequestThrottlerManager()
url_id_replacements_.ClearRef();
NetworkChangeNotifier::AddIPAddressObserver(this);
- NetworkChangeNotifier::AddOnlineStateObserver(this);
+ NetworkChangeNotifier::AddConnectionTypeObserver(this);
}
URLRequestThrottlerManager::~URLRequestThrottlerManager() {
NetworkChangeNotifier::RemoveIPAddressObserver(this);
- NetworkChangeNotifier::RemoveOnlineStateObserver(this);
+ NetworkChangeNotifier::RemoveConnectionTypeObserver(this);
// Since, for now, the manager object might conceivably go away before
// the entries, detach the entries' back-pointer to the manager.
@@ -166,7 +166,8 @@ void URLRequestThrottlerManager::OnIPAddressChanged() {
OnNetworkChange();
}
-void URLRequestThrottlerManager::OnOnlineStateChanged(bool online) {
+void URLRequestThrottlerManager::OnConnectionTypeChanged(
+ NetworkChangeNotifier::ConnectionType type) {
OnNetworkChange();
}
@@ -207,7 +208,7 @@ void URLRequestThrottlerManager::OnNetworkChange() {
// Remove all entries. Any entries that in-flight requests have a reference
// to will live until those requests end, and these entries may be
// inconsistent with new entries for the same URLs, but since what we
// want is a clean slate for the new connection state, this is OK.
url_entries_.clear();
requests_since_last_gc_ = 0;
}
@@ -207,7 +208,7 @@ void URLRequestThrottlerManager::OnNetworkChange() {
// to will live until those requests end, and these entries may be
// inconsistent with new entries for the same URLs, but since what we
- // want is a clean slate for the new connection state, this is OK.
+ // want is a clean slate for the new connection type, this is OK.
url_entries_.clear();
requests_since_last_gc_ = 0;